@@ -1,10 +1,9 @@
 /* ****************************************************************************
   This file is part of KBabel
 
-  Copyright (C) 1999-2000 by Matthias Kiefer
-                            <matthias.kiefer@gmx.de>
-		2001-2005 by Stanislav Visnovsky
-			    <visnovsky@kde.org>
+  Copyright (C) 1999-2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
+		2001-2005 by Stanislav Visnovsky <visnovsky@kde.org>
+  Copyright (C) 2006 by Nicolas GOUTTE <goutte@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -938,12 +937,23 @@ ConversionStatus Catalog::openURL(const KURL& url, const QString& package)
 	    return STOPPED;
 	}
 
-	if( error == OK || error == RECOVERED_PARSE_ERROR || error == HEADER_ERROR )
+	if( error == OK || error == RECOVERED_PARSE_ERROR || error == RECOVERED_HEADER_ERROR )
 	{
+            const uint entries = numberOfEntries();
+
+            if ( !entries )
+            {
+                // KBabel cannot work correctly with not any entry
+                kdWarning() << k_funcinfo << " No entries! Assuming parse error!" << endl;
+                delete filter;
+                return NO_ENTRY_ERROR;
+            }
+            
+            //kdDebug( KBABEL ) << k_funcinfo << " Success (full or partial) " << entries << endl;
 	    setModified(false);
 	    d->_url=url;
 
-	    if( package.isNull() )
+            if( package.isEmpty() )
 	    {
 		d->_packageName=QString::null;
 		d->_packageDir=QString::null;
@@ -953,7 +963,7 @@ ConversionStatus Catalog::openURL(const KURL& url, const QString& package)
 	    emit signalFileOpened(d->_readOnly);
 	    emit signalNumberOfFuzziesChanged(numberOfFuzzies());
 	    emit signalNumberOfUntranslatedChanged(numberOfUntranslated());
-	    emit signalTotalNumberChanged(numberOfEntries());
+	    emit signalTotalNumberChanged( entries );
 	}
 
 	delete filter;
@@ -1021,14 +1031,27 @@ ConversionStatus Catalog::openURL(const KURL& openUrl, const KURL& saveURL, cons
 	if( error == STOPPED )
         {
 	    delete filter;
+            KIO::NetAccess::removeTempFile(target);
 	    return STOPPED;
 	}
 
+        // Templates should not have recoverable errors (or they are bad templates)
 	if( error == OK )
 	{
+            const uint entries = numberOfEntries();
+
+            if ( !entries )
+            {
+                // KBabel cannot work correctly with not any entry
+                kdWarning() << k_funcinfo << " No entries! Assuming parse error!" << endl;
+                delete filter;
+                KIO::NetAccess::removeTempFile(target);
+                return NO_ENTRY_ERROR;
+            }
+            
            setModified(false);
            d->_url = saveURL;
-	   if( package.isNull() )
+           if( package.isEmpty() )
 	   {
 		d->_packageName=QString::null;
 		d->_packageDir=QString::null;
@@ -1038,7 +1061,7 @@ ConversionStatus Catalog::openURL(const KURL& openUrl, const KURL& saveURL, cons
            emit signalFileOpened(d->_readOnly);
            emit signalNumberOfFuzziesChanged(numberOfFuzzies());
            emit signalNumberOfUntranslatedChanged(numberOfUntranslated());
-           emit signalTotalNumberChanged(numberOfEntries());
+           emit signalTotalNumberChanged( entries );
         }
 
 	delete filter;
@@ -1085,15 +1108,16 @@ Msgfmt::Status Catalog::checkSyntax(QString& output, bool clearErrors)
       if( !d->_header.msgstr().isEmpty() )
          currentLine=d->_header.totalLines()+1;
 
-      QStringList lines = QStringList::split("\n",output);
-      for ( QStringList::Iterator it = lines.begin(); it != lines.end(); ++it )
+      // ### KDE4: return "lines" not "output"
+      const QStringList lines = QStringList::split("\n",output);
+      for ( QStringList::const_iterator it = lines.constBegin(); it != lines.constEnd(); ++it )
       {
-         if( (*it).contains(QRegExp("^.+:\\d+:")) )
+         if( (*it).find(QRegExp("^.+:\\d+:")) >= 0 )
          {
-            int begin=(*it).find(":",0)+1;
-            int end=(*it).find(":",begin);
+            const int begin=(*it).find(":",0)+1;
+            const int end=(*it).find(":",begin);
 
-            QString line=(*it).mid(begin,end-begin);
+            const QString line=(*it).mid(begin,end-begin);
 
             while( line.toInt() > currentLine )
             {
