@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -144,10 +144,10 @@ void HeaderEditor::slotUser1()
    header.setComment( _editor->commentEdit->text() );
    header.setMsgstr( _editor->headerEdit->text() );
 
-   header=_catalog->updatedHeader(header,false);
+   header=_catalog->updatedHeader(header,true);
 
-   _editor->headerEdit->setText(_catalog->header().msgstr().first());
-   _editor->commentEdit->setText(_catalog->header().comment());
+   _editor->headerEdit->setText(header.msgstr().first());
+   _editor->commentEdit->setText(header.comment());
 }
 
 
