@@ -2,12 +2,12 @@
                                 komparesaveoptionswidget.cpp  -  description
                                 -------------------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001 by Otto Bruggeman
+        copyright               : (C) 2001-2003 by Otto Bruggeman
                                   and John Firebaugh
         email                   : otto.bruggeman@home.nl
                                   jfirebaugh@kde.org
 ****************************************************************************/
- 
+
 /***************************************************************************
 **
 **   This program is free software; you can redistribute it and/or modify
@@ -37,27 +37,27 @@ KompareSaveOptionsWidget::KompareSaveOptionsWidget( QString source, QString dest
 	, m_destination( destination )
 {
 	m_settings = settings;
-	
+
 	m_directoryRequester->setMode( static_cast<KFile::Mode>(
 	    KFile::ExistingOnly | KFile::Directory | KFile::LocalOnly ) );
-	
+
 	KURL sourceURL;
 	KURL destinationURL;
 	sourceURL.setPath( source );
 	destinationURL.setPath( destination );
-	
+
 	// Find a common root.
 	KURL root( sourceURL );
-	while( !root.isMalformed() && !root.isParentOf( destinationURL ) ) {
+	while( root.isValid() && !root.isParentOf( destinationURL ) ) {
 		root = root.upURL();
 	}
-	
+
 	// If we found a common root, change to that directory and
 	// strip the common part from source and destination.
-	if( !root.isMalformed() ) {
+	if( root.isValid() ) {
 		m_directoryRequester->setURL( root.url() );
 	}
-	
+
 	connect( m_SmallerChangesCB,   SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
 	connect( m_LargeFilesCB,       SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
 	connect( m_IgnoreCaseCB,       SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
@@ -67,7 +67,6 @@ KompareSaveOptionsWidget::KompareSaveOptionsWidget( QString source, QString dest
 	connect( m_FunctionNamesCB,    SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
 	connect( m_RecursiveCB,        SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
 	connect( m_NewFilesCB,         SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
-	connect( m_AllTextCB,          SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
 	connect( m_ContextRB,          SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
 	connect( m_EdRB,               SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
 	connect( m_NormalRB,           SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
@@ -76,13 +75,13 @@ KompareSaveOptionsWidget::KompareSaveOptionsWidget( QString source, QString dest
 	connect( m_SideBySideRB,       SIGNAL(toggled(bool)), SLOT(updateCommandLine()) );
 	connect( m_ContextLinesSB,     SIGNAL(valueChanged(int)), SLOT(updateCommandLine()) );
 	connect( m_directoryRequester, SIGNAL(textChanged(const QString&)), SLOT(updateCommandLine()) );
-	
+
 	loadOptions();
 }
 
 KompareSaveOptionsWidget::~KompareSaveOptionsWidget()
 {
-	
+
 }
 
 QString KompareSaveOptionsWidget::directory() const
@@ -93,84 +92,84 @@ QString KompareSaveOptionsWidget::directory() const
 void KompareSaveOptionsWidget::updateCommandLine()
 {
 	QString cmdLine = "diff";
-	
+
 	QString options = "";
-	
-	switch( static_cast<Format>( m_FormatBG->id( m_FormatBG->selected() ) ) ) {
-	case Unified :
+
+	switch( static_cast<Kompare::Format>( m_FormatBG->id( m_FormatBG->selected() ) ) ) {
+	case Kompare::Unified :
 		cmdLine += " -U " + QString::number( m_ContextLinesSB->value() );
 		break;
-	case Context :
+	case Kompare::Context :
 		cmdLine += " -C " + QString::number( m_ContextLinesSB->value() );
 		break;
-	case RCS :
+	case Kompare::RCS :
 		options += "n";
 		break;
-	case Ed :
+	case Kompare::Ed :
 		options += "e";
 		break;
-	case SideBySide:
+	case Kompare::SideBySide:
 		options += "y";
 		break;
-	case Normal :
-	case Unknown :
+	case Kompare::Normal :
+	case Kompare::UnknownFormat :
 	default:
 		break;
 	}
-	
+
 	if ( m_SmallerChangesCB->isChecked() ) {
 		options += "d";
 	}
-	
+
 	if ( m_LargeFilesCB->isChecked() ) {
 		options += "H";
 	}
-	
+
 	if ( m_IgnoreCaseCB->isChecked() ){
 		options += "i";
 	}
-	
+
 	if ( m_ExpandTabsCB->isChecked() ) {
 		options += "t";
 	}
-	
+
 	if ( m_IgnoreEmptyLinesCB->isChecked() ) {
 		options += "B";
 	}
-	
+
 	if ( m_IgnoreWhiteSpaceCB->isChecked() ) {
 		options += "b";
 	}
-	
+
 	if ( m_FunctionNamesCB->isChecked() ) {
 		options += "p";
 	}
-	
+
 //	if (  ) {
 //		cmdLine += " -w";
 //	}
-	
+
 	if ( m_RecursiveCB->isChecked() ) {
 		options += "r";
 	}
-	
+
 	if( m_NewFilesCB->isChecked() ) {
 		options += "N";
 	}
-	
-	if( m_AllTextCB->isChecked() ) {
-		options += "a";
-	}
-	
+
+//	if( m_AllTextCB->isChecked() ) {
+//		options += "a";
+//	}
+
 	if( options.length() > 0 ) {
 		cmdLine += " -" + options;
 	}
-	
+
 	cmdLine += " -- ";
 	cmdLine += constructRelativePath( m_directoryRequester->url(), m_source );
 	cmdLine += " ";
 	cmdLine += constructRelativePath( m_directoryRequester->url(), m_destination );
-	
+
 	m_CommandLineLabel->setText( cmdLine );
 }
 
@@ -185,8 +184,8 @@ void KompareSaveOptionsWidget::loadOptions()
 	m_FunctionNamesCB->setChecked   ( m_settings->m_showCFunctionChange );
 	m_RecursiveCB->setChecked       ( m_settings->m_recursive );
 	m_NewFilesCB->setChecked        ( m_settings->m_newFiles );
-	m_AllTextCB->setChecked         ( m_settings->m_allText );
-	
+//	m_AllTextCB->setChecked         ( m_settings->m_allText );
+
 	m_ContextLinesSB->setValue      ( m_settings->m_linesOfContext );
 
 	m_FormatBG->setButton           ( m_settings->m_format );
@@ -205,11 +204,11 @@ void KompareSaveOptionsWidget::saveOptions()
 	m_settings->m_showCFunctionChange = m_FunctionNamesCB->isChecked();
 	m_settings->m_recursive           = m_RecursiveCB->isChecked();
 	m_settings->m_newFiles            = m_NewFilesCB->isChecked();
-	m_settings->m_allText             = m_AllTextCB->isChecked();
-	
+//	m_settings->m_allText             = m_AllTextCB->isChecked();
+
 	m_settings->m_linesOfContext      = m_ContextLinesSB->value();
 
-	m_settings->m_format = static_cast<Format>( m_FormatBG->id( m_FormatBG->selected() ) );
+	m_settings->m_format = static_cast<Kompare::Format>( m_FormatBG->id( m_FormatBG->selected() ) );
 
 }
 
