@@ -46,7 +46,7 @@ public:
     /**
      * Constructor, initialises a couple of variables
      */
-    XMLSchemaWriter(UMLDoc * doc, const char* name = 0);
+    XMLSchemaWriter();
 
     /**
      * Destructor, empty
@@ -59,17 +59,10 @@ public:
      */
     virtual void writeClass(UMLClassifier *c);
 
-    /**
-     * checks whether type is "XMLSchemaWriter"
-     *
-     * @param type
-     */
-    virtual bool isType (QString & type);
-
     /**
      * returns "XMLSchema"
      */
-    virtual QString getLanguage();
+    virtual Uml::Programming_Language getLanguage();
 
     /**
      * get list of reserved keywords
