@@ -5,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *  copyright (C) 2005-2006                                                *
+ *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -12,7 +14,6 @@
 // qt/kde includes
 #include <qmap.h>
 #include <qregexp.h>
-#include <kapplication.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <klocale.h>
@@ -62,6 +63,10 @@ void putAtGlobalScope(bool yesno) {
     bPutAtGlobalScope = yesno;
 }
 
+void assignUniqueIdOnCreation(bool yesno) {
+    Object_Factory::assignUniqueIdOnCreation(yesno);
+}
+
 bool newUMLObjectWasCreated() {
     return bNewUMLObjectWasCreated;
 }
@@ -122,6 +127,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
         const int isPointer = typeName.contains('*');
         const int isRef = typeName.contains('&');
         typeName.remove(QRegExp("[^\\w:\\. ].*$"));
+        typeName = typeName.simplifyWhiteSpace();
         UMLObject *origType = umldoc->findUMLObject(typeName, Uml::ot_UMLObject, parentPkg);
         if (origType == NULL) {
             // Still not found. Create the stripped down type.
@@ -145,8 +151,8 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                         parentPkg = static_cast<UMLPackage*>(o);
                         continue;
                     }
-                    int wantNamespace = 1;
-                    /* We know std and Qt are always a namespaces */
+                    int wantNamespace = KMessageBox::Yes;
+                    /* We know std and Qt are namespaces */
                     if (scopeName != "std" && scopeName != "Qt") {
                         wantNamespace = KMessageBox::questionYesNo(NULL,
                                         i18n("Is the scope %1 a namespace or a class?").arg(scopeName),
@@ -155,7 +161,6 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                     }
                     Uml::Object_Type ot = (wantNamespace == KMessageBox::Yes ? Uml::ot_Package : Uml::ot_Class);
                     o = Object_Factory::createUMLObject(ot, scopeName, parentPkg);
-                    kapp->processEvents();
                     parentPkg = static_cast<UMLPackage*>(o);
                     UMLListView *listView = UMLApp::app()->getListView();
                     UMLListViewItem *lvitem = listView->findUMLObject(o);
@@ -169,7 +174,6 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                 t = Uml::ot_Class;
             origType = Object_Factory::createUMLObject(t, typeName, parentPkg);
             bNewUMLObjectWasCreated = true;
-            kapp->processEvents();
         }
         if (isConst || isAdorned) {
             // Create the full given type (including adornments.)
@@ -179,8 +183,9 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                 parentPkg = NULL;
                 bPutAtGlobalScope = false;
             }
-            o = Object_Factory::createUMLObject(Uml::ot_Datatype, name, parentPkg);
-            kapp->processEvents();
+            o = Object_Factory::createUMLObject(Uml::ot_Datatype, name, parentPkg,
+                                                false,  //prepend
+                                                false); //solicitNewName
             UMLDatatype *dt = static_cast<UMLDatatype*>(o);
             UMLClassifier *c = dynamic_cast<UMLClassifier*>(origType);
             if (c)
@@ -220,7 +225,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
 }
 
 UMLOperation* makeOperation(UMLClassifier *parent, const QString &name) {
-    UMLOperation *op = new UMLOperation(parent, name);
+    UMLOperation *op = Object_Factory::createOperation(parent, name);
     return op;
 }
 
@@ -261,7 +266,8 @@ void insertMethod(UMLClassifier *klass, UMLOperation *op,
                                bool isFriend, bool isConstructor,
                                QString comment) {
     op->setVisibility(scope);
-    if (!type.isEmpty()) {  // return type may be missing (constructor/destructor)
+    if (!type.isEmpty()     // return type may be missing (constructor/destructor)
+        && type != "void") {
         if (type == klass->getName()) {
             op->setType(klass);
         } else {
@@ -304,7 +310,7 @@ UMLAttribute* addMethodParameter(UMLOperation *method,
         typeObj = createUMLObject(Uml::ot_UMLObject, type, owner);
         bPutAtGlobalScope = false;
     }
-    UMLAttribute *attr = new UMLAttribute(method, name);
+    UMLAttribute *attr = Object_Factory::createAttribute(method, name);
     attr->setType(typeObj);
     method->addParm(attr);
     return attr;
@@ -341,5 +347,12 @@ void addIncludePath(QString path) {
         incPathList.append(path);
 }
 
+
+bool isDatatype(QString name, UMLPackage *parentPkg) {
+    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLObject * o = umldoc->findUMLObject(name, Uml::ot_Datatype, parentPkg);
+    return (o!=NULL);
+}
+
 }  // end namespace Import_Utils
 
