@@ -41,8 +41,7 @@ MessageWidget::MessageWidget(UMLView * view, ObjectWidget* a, ObjectWidget* b,
         y -= m_pOw[Uml::B]->getHeight() / 2;
         m_pOw[Uml::B]->setY(y);
     }
-    UMLWidget::m_bResizable = (m_pOw[Uml::A] == m_pOw[Uml::B]);
-
+    updateResizability();
     calculateWidget();
     y = y < getMinHeight() ? getMinHeight() : y;
     y = y > getMaxHeight() ? getMaxHeight() : y;
@@ -71,6 +70,14 @@ void MessageWidget::init() {
 MessageWidget::~MessageWidget() {
 }
 
+void MessageWidget::updateResizability() {
+    if (m_sequenceMessageType == Uml::sequence_message_synchronous ||
+        m_pOw[Uml::A] == m_pOw[Uml::B])
+        UMLWidget::m_bResizable = true;
+    else
+        UMLWidget::m_bResizable = false;
+}
+
 void MessageWidget::draw(QPainter& p, int offsetX, int offsetY) {
     if(!m_pOw[Uml::A] || !m_pOw[Uml::B]) {
         return;
@@ -477,7 +484,11 @@ UMLOperation *MessageWidget::getOperation() {
 }
 
 void MessageWidget::setOperation(UMLOperation *op) {
+    if (m_pObject && m_pFText)
+        disconnect(m_pObject, SIGNAL(modified()), m_pFText, SLOT(setMessageText()));
     m_pObject = op;
+    if (m_pObject && m_pFText)
+        connect(m_pObject, SIGNAL(modified()), m_pFText, SLOT(setMessageText()));
 }
 
 QString MessageWidget::getCustomOpText() {
@@ -737,7 +748,7 @@ int MessageWidget::getMaxHeight() {
 
 void MessageWidget::setWidget(ObjectWidget * ow, Uml::Role_Type role) {
     m_pOw[role] = ow;
-    UMLWidget::m_bResizable = (m_pOw[Uml::A] == m_pOw[Uml::B]);
+    updateResizability();
 }
 
 ObjectWidget* MessageWidget::getWidget(Uml::Role_Type role) {
@@ -805,34 +816,18 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement) {
         << ID2STR(bId) << " is not an ObjectWidget" << endl;
         return false;
     }
-    UMLWidget::m_bResizable = (m_pOw[Uml::A] == m_pOw[Uml::B]);
+    updateResizability();
 
     UMLClassifier *c = dynamic_cast<UMLClassifier*>( pWB->getUMLObject() );
+    UMLOperation *op = NULL;
     if (c) {
         Uml::IDType opId = STR2ID(m_CustomOp);
-        UMLOperation *op = dynamic_cast<UMLOperation*>( c->findChildObjectById(opId, true) );
+        op = dynamic_cast<UMLOperation*>( c->findChildObjectById(opId, true) );
         if (op) {
             // If the UMLOperation is set, m_CustomOp isn't used anyway.
             // Just setting it empty for the sake of sanity.
             m_CustomOp = QString::null;
-        } else {
-            // Previous umbrello versions saved the operation text
-            // instead of the xmi.id of the operation.
-            // For backward compatibility, attempt to determine the
-            // m_pOperation from the operation text:
-            Model_Utils::OpDescriptor od;
-            Model_Utils::Parse_Status st = Model_Utils::parseOperation(m_CustomOp, od, c);
-            if (st == Model_Utils::PS_OK) {
-                bool isExistingOp = false;
-                UMLObject *o = c->createOperation(od.m_name, &isExistingOp, &od.m_args);
-                op = static_cast<UMLOperation*>(o);
-                if (od.m_pReturnType) {
-                    op->setType(od.m_pReturnType);
-                }
-                m_CustomOp = QString::null;
-            }
         }
-        setOperation(op);
     }
 
     Uml::IDType textId = STR2ID(textid);
@@ -871,6 +866,8 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement) {
             << tag << endl;
         }
     }
+    if (op)                // Do it here and not earlier because now we have the
+        setOperation(op);  // m_pFText and setOperation() can make connections.
 
     // always need this
     setLinkAndTextPos();
