@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2004-2005
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *  copyright (C) 2004-2006                                                *
+ *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -105,10 +102,12 @@ UMLObject* findUMLObject(UMLObjectList inList, QString name,
                          UMLObject *currentObj /* = NULL */) {
     const bool caseSensitive = UMLApp::app()->activeLanguageIsCaseSensitive();
     QStringList components;
-    if (name.contains("::"))
-        components = QStringList::split("::", name);
-    else if (name.contains("."))
-        components = QStringList::split(".", name);
+    if (type != Uml::ot_Datatype) {
+        if (name.contains("::"))
+            components = QStringList::split("::", name);
+        else if (name.contains("."))
+            components = QStringList::split(".", name);
+    }
     QString nameWithoutFirstPrefix;
     if (components.size() > 1) {
         if (name.contains(QRegExp("[^\\w:\\.]"))) {
@@ -255,47 +254,6 @@ QString uniqObjectName(Uml::Object_Type type, QString prefix,
     return name;
 }
 
-UMLObject* createChildObject(UMLObject* umlobject, Uml::Object_Type type) {
-    UMLObject* returnObject = NULL;
-    switch (type) {
-    case Uml::ot_Attribute: {
-            UMLClassifier *c = dynamic_cast<UMLClassifier*>(umlobject);
-            if (c && !c->isInterface())
-                returnObject = c->createAttribute();
-            break;
-        }
-    case Uml::ot_Operation: {
-            UMLClassifier *c = dynamic_cast<UMLClassifier*>(umlobject);
-            if (c)
-                returnObject = c->createOperation();
-            break;
-        }
-    case Uml::ot_Template: {
-            UMLClassifier *c = dynamic_cast<UMLClassifier*>(umlobject);
-            if (c)
-                returnObject = c->createTemplate();
-            break;
-        }
-    case Uml::ot_EnumLiteral: {
-            UMLEnum* umlenum = dynamic_cast<UMLEnum*>(umlobject);
-            if (umlenum) {
-                returnObject = umlenum->createEnumLiteral();
-            }
-            break;
-        }
-    case Uml::ot_EntityAttribute: {
-            UMLEntity* umlentity = dynamic_cast<UMLEntity*>(umlobject);
-            if (umlentity) {
-                returnObject = umlentity->createEntityAttribute();
-            }
-            break;
-        }
-    default:
-        kdDebug() << "ERROR UMLDoc::createChildObject type:" << type << endl;
-    }
-    return returnObject;
-}
-
 bool isCommonXMIAttribute( const QString &tag ) {
     bool retval = (Uml::tagEq(tag, "name") ||
                    Uml::tagEq(tag, "visibility") ||
@@ -329,6 +287,18 @@ bool isCommonDataType(QString type) {
     return false;
 }
 
+bool isClassifierListitem(Uml::Object_Type type) {
+    if (type == Uml::ot_Attribute ||
+        type == Uml::ot_Operation ||
+        type == Uml::ot_Template ||
+        type == Uml::ot_EntityAttribute ||
+        type == Uml::ot_EnumLiteral) {
+        return true;
+    } else {
+        return false;
+    }
+}
+
 int stringToDirection(QString input, Uml::Parameter_Direction & result) {
     QRegExp dirx("^(in|out|inout)");
     int pos = dirx.search(input);
