@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2005
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *  copyright (C) 2002-2006                                                *
+ *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
  ***************************************************************************/
 
 #include <qregexp.h>
@@ -263,6 +260,10 @@ Uml::Object_Type UMLObject::getBaseType() const {
     return m_BaseType;
 }
 
+void UMLObject::setBaseType(Uml::Object_Type ot) {
+    m_BaseType = ot;
+}
+
 Uml::IDType UMLObject::getID() const {
     return m_nId;
 }
@@ -377,6 +378,18 @@ QString UMLObject::getSecondaryId() const {
     return m_SecondaryId;
 }
 
+void UMLObject::setSecondaryId(QString id) {
+    m_SecondaryId = id;
+}
+
+QString UMLObject::getSecondaryFallback() const {
+    return m_SecondaryFallback;
+}
+
+void UMLObject::setSecondaryFallback(QString id) {
+    m_SecondaryFallback = id;
+}
+
 void UMLObject::maybeSignalObjectCreated() {
     if (!m_bCreationWasSignalled &&
             m_BaseType != Uml::ot_Stereotype &&
@@ -389,29 +402,44 @@ void UMLObject::maybeSignalObjectCreated() {
 }
 
 bool UMLObject::resolveRef() {
-    if (m_pSecondary || m_SecondaryId.isEmpty()) {
+    if (m_pSecondary || (m_SecondaryId.isEmpty() && m_SecondaryFallback.isEmpty())) {
         maybeSignalObjectCreated();
         return true;
     }
 #ifdef VERBOSE_DEBUGGING
     kdDebug() << "UMLObject::resolveRef(" << m_Name << "): m_SecondaryId is "
-    << m_SecondaryId << endl;
+              << m_SecondaryId << endl;
 #endif
     UMLDoc *pDoc = UMLApp::app()->getDocument();
     // In the new, XMI standard compliant save format,
     // the type is the xmi.id of a UMLClassifier.
-    Uml::IDType id = STR2ID(m_SecondaryId);
-    m_pSecondary = pDoc->findObjectById(id);
-    if (m_pSecondary != NULL) {
-        m_SecondaryId = "";
-        maybeSignalObjectCreated();
-        return true;
+    if (! m_SecondaryId.isEmpty()) {
+        m_pSecondary = pDoc->findObjectById(STR2ID(m_SecondaryId));
+        if (m_pSecondary != NULL) {
+            if (m_pSecondary->getBaseType() == Uml::ot_Stereotype) {
+                m_pStereotype = static_cast<UMLStereotype*>(m_pSecondary);
+                m_pStereotype->incrRefCount();
+                m_pSecondary = NULL;
+            }
+            m_SecondaryId = "";
+            maybeSignalObjectCreated();
+            return true;
+        }
     }
     if (!pDoc->isNativeXMIFile() || !m_SecondaryId.contains(QRegExp("\\D"))) {
-        kdError() << "UMLObject::resolveRef(" << m_Name
-        << "): cannot find type with id "
-        << ID2STR(id) << endl;
-        return false;
+        if (m_SecondaryFallback.isEmpty()) {
+            kdError() << "UMLObject::resolveRef(" << m_Name
+                      << "): cannot find type with id "
+                      << m_SecondaryId << endl;
+            return false;
+        }
+#ifdef VERBOSE_DEBUGGING
+        kdDebug() << "UMLObject::resolveRef(" << m_Name 
+                  << "): could not resolve secondary ID " << m_SecondaryId
+                  << ", using secondary fallback " << m_SecondaryFallback
+                  << endl;
+#endif
+        m_SecondaryId = m_SecondaryFallback;
     }
     // Assume we're dealing with the older Umbrello format where
     // the type name was saved in the "type" attribute rather
@@ -642,9 +670,9 @@ bool UMLObject::loadFromXMI( QDomElement & element) {
     }
     /**** End of XMI_FLAT_PACKAGES and old files handling ****************/
 
-    // If the name is not set, let's check whether the attributes are saved
-    // as child nodes.
-    if (m_Name.isEmpty()) {
+    // If the node has child nodes, check whether attributes can be
+    // extracted from them.
+    if (element.hasChildNodes()) {
         QDomNode node = element.firstChild();
         if (node.isComment())
             node = node.nextSibling();
@@ -675,6 +703,29 @@ bool UMLObject::loadFromXMI( QDomElement & element) {
                 if (ownerScope.isEmpty())
                     ownerScope = elem.text();
                 m_bStatic = (ownerScope == "classifier");
+            } else if (Uml::tagEq(tag, "stereotype")) {
+                QString stereo = elem.attribute("xmi.value", "");
+                if (stereo.isEmpty() && elem.hasChildNodes()) {
+                    /* like so:
+                     <UML:ModelElement.stereotype>
+                       <UML:Stereotype xmi.idref = '07CD'/>
+                     </UML:ModelElement.stereotype>
+                     */
+                    QDomNode stereoNode = elem.firstChild();
+                    QDomElement stereoElem = stereoNode.toElement();
+                    tag = stereoElem.tagName();
+                    if (Uml::tagEq(tag, "Stereotype")) {
+                        stereo = stereoElem.attribute("xmi.idref", "");
+                    }
+                }
+                if (! stereo.isEmpty()) {
+                    Uml::IDType stereoID = STR2ID(stereo);
+                    m_pStereotype = umldoc->findStereotypeById(stereoID);
+                    if (m_pStereotype)
+                        m_pStereotype->incrRefCount();
+                    else
+                        m_SecondaryId = stereo;  // leave it to resolveRef()
+                }
             }
             node = node.nextSibling();
             if (node.isComment())
