@@ -404,12 +404,12 @@ public:
     AssociationWidget * findAssocWidget(Uml::Association_Type at,
                                         UMLWidget *pWidgetA, UMLWidget *pWidgetB);
 
-
     /**
-        calls findAssocWidget on three possible types:
-        Uml::at_Aggregation << Uml::at_Composition << Uml::at_Containment
-        */
+     * calls findAssocWidget on three possible types:
+     * Uml::at_Aggregation << Uml::at_Composition << Uml::at_Containment
+     */
     AssociationWidget * findAssocWidget(UMLWidget *pWidgetA, UMLWidget *pWidgetB);
+
     /**
      * Remove a widget from view.
      *
@@ -910,6 +910,13 @@ public:
         m_pFirstSelectedWidget = w;
     }
 
+    /**
+     * Return pointer to the first selected widget (for multi-selection)
+     */
+    UMLWidget* getFirstMultiSelectedWidget() {
+        return m_SelectedList.first();
+    }
+
     /**
      * Return the current UMLWidget we are on.
      */
