@@ -418,9 +418,12 @@ public:
      */
     virtual void setShowStereotype(bool _status);
 
-    virtual void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
-
-    virtual bool loadFromXMI( QDomElement & qElement );
+    /**
+     * Show a properties dialog for a UMLWidget.
+     *
+     * @return  True if the widget was modified.
+     */
+    bool showProperties();
 
     /**
      * Returns true if the Activate method has been called for this instance
@@ -514,6 +517,10 @@ public:
      */
     virtual void moveEvent(QMoveEvent *) { }
 
+    virtual void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
+
+    virtual bool loadFromXMI( QDomElement & qElement );
+
 protected:
     /**
      * Apply possible constraints to the given candidate width and height.
@@ -533,7 +540,7 @@ protected:
      * @param offsetX The x-coordinate for drawing.
      * @param offsetY The y-coordinate for drawing.
      */
-    virtual void drawSelected(QPainter * p, int offsetX, int offsetY, bool resizeable = true);
+    virtual void drawSelected(QPainter * p, int offsetX, int offsetY);
 
     /**
      * Overrides default method.
@@ -654,7 +661,7 @@ protected:
     int            m_nOldX, m_nOldY, m_nPosX, m_origZ;
     ListPopupMenu *m_pMenu;
     UMLDoc        *m_pDoc;  ///< shortcut for UMLApp::app()->getDocument()
-    bool           m_bResizing;
+    bool           m_bResizable, m_bResizing;
     int            m_nPressOffsetX, m_nPressOffsetY;
     int            m_nOldH, m_nOldW;
     QFontMetrics  *m_pFontMetrics[FT_INVALID];
